==> mktcenter-service-threetree-1.0-20250918.102922-20-sources.jar: com/bizvane/mktcenterservice/interfaces/tree3/MktActivityCertificationService.java <==
package com.bizvane.mktcenterservice.interfaces.tree3;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.ActivityCertificationUploadPhoneZipReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SaveOrUpdateActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationRecordReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRecordRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MktActivityCertificationService {
    ResponseData<String> saveOrUpdate(SaveOrUpdateActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<GetDetailActivityCertificationRespVO> getDetail(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> selectPage(SelectPageActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> disable(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRecordRespVO>> selectRecordPage(SelectPageActivityCertificationRecordReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> uploadPhoneZipFile(ActivityCertificationUploadPhoneZipReqVO reqVO, SysAccountPO sysAccountPO);

}

==> mktcenter-service-threetree-1.0-20250924.095103-22-sources.jar: com/bizvane/mktcenterservice/interfaces/tree3/MktActivityCertificationService.java <==
package com.bizvane.mktcenterservice.interfaces.tree3;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.ActivityCertificationUploadPhoneZipReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SaveOrUpdateActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationRecordReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.*;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MktActivityCertificationService {
    ResponseData<String> saveOrUpdate(SaveOrUpdateActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<GetDetailActivityCertificationRespVO> getDetail(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<GetDetailNumActivityCertificationRespVO> getDetailNum(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> selectPage(SelectPageActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> disable(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRecordRespVO>> selectRecordPage(SelectPageActivityCertificationRecordReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<SelectActivityCertificationNumRespVO> getActivityCertificationNum(SysAccountPO sysAccountPO);

    ResponseData<String> uploadPhoneZipFile(ActivityCertificationUploadPhoneZipReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> updateActivityCertificationState();
}
